@@ -12,7 +12,7 @@ import log
 from cached_property import cached_property
 
 from . import config, formats, hooks
-from .converters import Converter, List, map_type
+from .converters import Converter, List, map_type, resolve
 from .types import Missing, Trilean
 from .utils import display, get_default_field_value, recursive_update, write
 
@@ -287,10 +287,10 @@ def create_mapper(obj, root=None) -> Mapper:
     if attrs is None and dataclasses.is_dataclass(obj):
         attrs = {}
         log.debug(f'Mapping attributes for {obj.__class__} object')
-        for field in dataclasses.fields(obj):
+        for field in [field for field in dataclasses.fields(obj) if field.init]:
             self_name = f'self.{field.name}'
             if pattern is None or self_name not in pattern:
-                attrs[field.name] = map_type(field.type, name=field.name)  # type: ignore
+                attrs[field.name] = map_type(resolve(field.type, obj), name=field.name)  # type: ignore
 
     return Mapper(
         obj,
