@@ -2,7 +2,7 @@
 
 from dataclasses import dataclass
 from enum import Enum
-from typing import ByteString, Dict, List, Mapping, Optional
+from typing import ByteString, Dict, List, Mapping, Optional, Set
 
 import pytest
 from ruamel.yaml.scalarstring import LiteralScalarString
@@ -39,6 +39,8 @@ class Color(Enum):
 IntegerList = converters.List.of_type(converters.Integer)
 StringList = converters.List.of_type(converters.String)
 MyDict = converters.Dictionary.of_mapping(converters.String, converters.Integer)
+IntegerSet = converters.Set.of_type(converters.Integer)
+StringSet = converters.Set.of_type(converters.String)
 MyDataclassConverter = converters.map_type(MyDataclass)
 MyDataclassConverterList = converters.map_type(List[MyDataclass])
 
@@ -62,6 +64,20 @@ def describe_map_type():
         with expect.raises(TypeError, "Type is required with 'List' annotation"):
             converters.map_type(List)
 
+    def it_handles_set_annotations(expect):
+        converter = converters.map_type(Set[str])
+        expect(converter.__name__) == 'StringSet'
+        expect(converter.CONVERTER) == converters.String
+
+    def it_handles_set_annotations_of_dataclasses(expect):
+        converter = converters.map_type(Set[MyDataclass])
+        expect(converter.__name__) == 'MyDataclassConverterSet'
+        expect(converter.CONVERTER.__name__) == 'MyDataclassConverter'
+
+    def it_requires_set_annotations_to_have_a_type(expect):
+        with expect.raises(TypeError, "Type is required with 'Set' annotation"):
+            converters.map_type(Set)
+
     def it_handles_dict_annotations(expect):
         converter = converters.map_type(Dict[str, int])
         expect(converter.__name__) == 'StringIntegerDict'
@@ -96,6 +112,11 @@ def describe_map_type():
         converter = converters.map_type('float')
         expect(converter.TYPE) == float
 
+    def it_handles_string_type_annotations_for_extensions(expect):
+        converter = converters.map_type('Number')
+        expect(converter.TYPE) == float
+        expect(converter.__name__) == 'Number'
+
     def it_rejects_unknown_types(expect):
         with expect.raises(
             TypeError,
@@ -161,6 +182,12 @@ def describe_converter():
                 (MyDict, None, {}),
                 (MyDict, {}, {}),
                 (MyDict, {'a': 1}, {'a': 1}),
+                (IntegerSet, set(), set()),
+                (IntegerSet, '1, 1.1, 1.9, 2.3, 3', {1, 2, 3}),
+                (IntegerSet, '42', {42}),
+                (IntegerSet, 42, {42}),
+                (IntegerSet, None, set()),
+                (IntegerSet, [None], set()),
                 (MyDataclassConverter, None, MyDataclass(foobar=0)),
                 (MyDataclassConverter, MyDataclass(42), MyDataclass(foobar=42)),
                 (MyDataclassConverterList, None, []),
@@ -187,6 +214,10 @@ def describe_converter():
             with expect.raises(ValueError):
                 convert(42)
 
+        def when_optional_enum(expect):
+            convert = converters.map_type(Optional[Color]).to_python_value
+            expect(convert(None)).is_(None)
+
         def when_invalid(expect):
             message = "invalid literal for int() with base 10: 'a'"
             with expect.raises(ValueError, message):
@@ -243,6 +274,14 @@ def describe_converter():
                 (StringList, [123, True, False], ['123', 'True', 'False']),
                 (StringList, [], [None]),
                 (StringList, None, [None]),
+                # Sets
+                (StringSet, 'ab', ['ab']),
+                (StringSet, ('b', 1, 'A'), ['b', '1', 'A']),
+                (StringSet, {'b', 1, 'A'}, ['1', 'A', 'b']),
+                (StringSet, 42, ['42']),
+                (StringSet, [123, True, False], ['123', 'True', 'False']),
+                (StringSet, [], [None]),
+                (StringSet, None, [None]),
                 # Dataclasses
                 (MyDataclassConverter, None, {'foobar': 0, 'flag': False}),
                 (MyDataclassConverter, {'foobar': 42}, {'foobar': 42, 'flag': False}),
@@ -269,6 +308,10 @@ def describe_converter():
             convert = converters.map_type(Color).to_preserialization_data
             expect(convert(Color.RED)) == 1
 
+        def when_optional_enum(expect):
+            convert = converters.map_type(Optional[Color]).to_preserialization_data
+            expect(convert(None)).is_(None)
+
         def when_invalid(expect):
             message = "invalid literal for int() with base 10: 'a'"
             with expect.raises(ValueError, message):
@@ -294,6 +337,13 @@ def describe_converter():
             data = IntegerList.to_preserialization_data([2], default_to_skip=[1])
             expect(data) == [2]
 
+        def when_Set_with_default(expect):
+            data = IntegerSet.to_preserialization_data([1], default_to_skip=[1])
+            expect(data) == [None]
+
+            data = IntegerSet.to_preserialization_data([2], default_to_skip=[1])
+            expect(data) == [2]
+
         def when_dict_with_default(expect):
             data = MyDict.to_preserialization_data({'a': 1}, default_to_skip={'a': 1})
             expect(data) == {}
@@ -322,6 +372,11 @@ def describe_converter():
             data = StringList.to_preserialization_data([])
             expect(data) == []
 
+        def when_empty_set_and_diff_minimization_disabled(expect, monkeypatch):
+            monkeypatch.setattr(settings, 'MINIMIZE_LIST_DIFFS', False)
+            data = StringSet.to_preserialization_data([])
+            expect(data) == []
+
 
 def describe_register():
     def with_new_type(expect):
