@@ -1,6 +1,7 @@
 """Internal helper functions."""
 
 import dataclasses
+import time
 from contextlib import suppress
 from functools import lru_cache
 from pathlib import Path
@@ -10,12 +11,19 @@ from typing import Any, Dict, Union
 
 import log
 
+from . import settings
 from .types import Missing
 
 
 cached = lru_cache()
 
 
+def subclasses(cls):
+    return set(cls.__subclasses__()).union(
+        [s for c in cls.__subclasses__() for s in subclasses(c)]
+    )
+
+
 def get_default_field_value(instance, name):
     for field in dataclasses.fields(instance):
         if field.name == name:
@@ -114,6 +122,7 @@ def write(filename_or_path: Union[str, Path], text: str, *, display=False) -> No
 
     path.parent.mkdir(parents=True, exist_ok=True)
     path.write_text(text)
+    time.sleep(settings.WRITE_DELAY)  # ensure the file modification time changes
 
 
 def read(filename: str, *, display=False) -> str:
